@@ -19,13 +19,15 @@ import re
 from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
-import google.api_core.client_options as ClientOptions  # type: ignore
+from google.api_core.client_options import ClientOptions  # type: ignore
 from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+OptionalRetry = Union[retries.Retry, object]
+
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.metastore_v1.services.dataproc_metastore import pagers
@@ -198,17 +200,17 @@ class DataprocMetastoreAsyncClient:
 
     async def list_services(
         self,
-        request: metastore.ListServicesRequest = None,
+        request: Union[metastore.ListServicesRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListServicesAsyncPager:
         r"""Lists services in a project and location.
 
         Args:
-            request (:class:`google.cloud.metastore_v1.types.ListServicesRequest`):
+            request (Union[google.cloud.metastore_v1.types.ListServicesRequest, dict]):
                 The request object. Request message for
                 [DataprocMetastore.ListServices][google.cloud.metastore.v1.DataprocMetastore.ListServices].
             parent (:class:`str`):
@@ -280,17 +282,17 @@ class DataprocMetastoreAsyncClient:
 
     async def get_service(
         self,
-        request: metastore.GetServiceRequest = None,
+        request: Union[metastore.GetServiceRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> metastore.Service:
         r"""Gets the details of a single service.
 
         Args:
-            request (:class:`google.cloud.metastore_v1.types.GetServiceRequest`):
+            request (Union[google.cloud.metastore_v1.types.GetServiceRequest, dict]):
                 The request object. Request message for
                 [DataprocMetastore.GetService][google.cloud.metastore.v1.DataprocMetastore.GetService].
             name (:class:`str`):
@@ -353,12 +355,12 @@ class DataprocMetastoreAsyncClient:
 
     async def create_service(
         self,
-        request: metastore.CreateServiceRequest = None,
+        request: Union[metastore.CreateServiceRequest, dict] = None,
         *,
         parent: str = None,
         service: metastore.Service = None,
         service_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -366,7 +368,7 @@ class DataprocMetastoreAsyncClient:
         location.
 
         Args:
-            request (:class:`google.cloud.metastore_v1.types.CreateServiceRequest`):
+            request (Union[google.cloud.metastore_v1.types.CreateServiceRequest, dict]):
                 The request object. Request message for
                 [DataprocMetastore.CreateService][google.cloud.metastore.v1.DataprocMetastore.CreateService].
             parent (:class:`str`):
@@ -468,18 +470,18 @@ class DataprocMetastoreAsyncClient:
 
     async def update_service(
         self,
-        request: metastore.UpdateServiceRequest = None,
+        request: Union[metastore.UpdateServiceRequest, dict] = None,
         *,
         service: metastore.Service = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Updates the parameters of a single service.
 
         Args:
-            request (:class:`google.cloud.metastore_v1.types.UpdateServiceRequest`):
+            request (Union[google.cloud.metastore_v1.types.UpdateServiceRequest, dict]):
                 The request object. Request message for
                 [DataprocMetastore.UpdateService][google.cloud.metastore.v1.DataprocMetastore.UpdateService].
             service (:class:`google.cloud.metastore_v1.types.Service`):
@@ -569,17 +571,17 @@ class DataprocMetastoreAsyncClient:
 
     async def delete_service(
         self,
-        request: metastore.DeleteServiceRequest = None,
+        request: Union[metastore.DeleteServiceRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Deletes a single service.
 
         Args:
-            request (:class:`google.cloud.metastore_v1.types.DeleteServiceRequest`):
+            request (Union[google.cloud.metastore_v1.types.DeleteServiceRequest, dict]):
                 The request object. Request message for
                 [DataprocMetastore.DeleteService][google.cloud.metastore.v1.DataprocMetastore.DeleteService].
             name (:class:`str`):
@@ -663,17 +665,17 @@ class DataprocMetastoreAsyncClient:
 
     async def list_metadata_imports(
         self,
-        request: metastore.ListMetadataImportsRequest = None,
+        request: Union[metastore.ListMetadataImportsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListMetadataImportsAsyncPager:
         r"""Lists imports in a service.
 
         Args:
-            request (:class:`google.cloud.metastore_v1.types.ListMetadataImportsRequest`):
+            request (Union[google.cloud.metastore_v1.types.ListMetadataImportsRequest, dict]):
                 The request object. Request message for
                 [DataprocMetastore.ListMetadataImports][google.cloud.metastore.v1.DataprocMetastore.ListMetadataImports].
             parent (:class:`str`):
@@ -745,17 +747,17 @@ class DataprocMetastoreAsyncClient:
 
     async def get_metadata_import(
         self,
-        request: metastore.GetMetadataImportRequest = None,
+        request: Union[metastore.GetMetadataImportRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> metastore.MetadataImport:
         r"""Gets details of a single import.
 
         Args:
-            request (:class:`google.cloud.metastore_v1.types.GetMetadataImportRequest`):
+            request (Union[google.cloud.metastore_v1.types.GetMetadataImportRequest, dict]):
                 The request object. Request message for
                 [DataprocMetastore.GetMetadataImport][google.cloud.metastore.v1.DataprocMetastore.GetMetadataImport].
             name (:class:`str`):
@@ -818,12 +820,12 @@ class DataprocMetastoreAsyncClient:
 
     async def create_metadata_import(
         self,
-        request: metastore.CreateMetadataImportRequest = None,
+        request: Union[metastore.CreateMetadataImportRequest, dict] = None,
         *,
         parent: str = None,
         metadata_import: metastore.MetadataImport = None,
         metadata_import_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -831,7 +833,7 @@ class DataprocMetastoreAsyncClient:
         location.
 
         Args:
-            request (:class:`google.cloud.metastore_v1.types.CreateMetadataImportRequest`):
+            request (Union[google.cloud.metastore_v1.types.CreateMetadataImportRequest, dict]):
                 The request object. Request message for
                 [DataprocMetastore.CreateMetadataImport][google.cloud.metastore.v1.DataprocMetastore.CreateMetadataImport].
             parent (:class:`str`):
@@ -932,11 +934,11 @@ class DataprocMetastoreAsyncClient:
 
     async def update_metadata_import(
         self,
-        request: metastore.UpdateMetadataImportRequest = None,
+        request: Union[metastore.UpdateMetadataImportRequest, dict] = None,
         *,
         metadata_import: metastore.MetadataImport = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -945,7 +947,7 @@ class DataprocMetastoreAsyncClient:
         supported to be updated.
 
         Args:
-            request (:class:`google.cloud.metastore_v1.types.UpdateMetadataImportRequest`):
+            request (Union[google.cloud.metastore_v1.types.UpdateMetadataImportRequest, dict]):
                 The request object. Request message for
                 [DataprocMetastore.UpdateMetadataImport][google.cloud.metastore.v1.DataprocMetastore.UpdateMetadataImport].
             metadata_import (:class:`google.cloud.metastore_v1.types.MetadataImport`):
@@ -1035,16 +1037,16 @@ class DataprocMetastoreAsyncClient:
 
     async def export_metadata(
         self,
-        request: metastore.ExportMetadataRequest = None,
+        request: Union[metastore.ExportMetadataRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Exports metadata from a service.
 
         Args:
-            request (:class:`google.cloud.metastore_v1.types.ExportMetadataRequest`):
+            request (Union[google.cloud.metastore_v1.types.ExportMetadataRequest, dict]):
                 The request object. Request message for
                 [DataprocMetastore.ExportMetadata][google.cloud.metastore.v1.DataprocMetastore.ExportMetadata].
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -1095,18 +1097,18 @@ class DataprocMetastoreAsyncClient:
 
     async def restore_service(
         self,
-        request: metastore.RestoreServiceRequest = None,
+        request: Union[metastore.RestoreServiceRequest, dict] = None,
         *,
         service: str = None,
         backup: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Restores a service from a backup.
 
         Args:
-            request (:class:`google.cloud.metastore_v1.types.RestoreServiceRequest`):
+            request (Union[google.cloud.metastore_v1.types.RestoreServiceRequest, dict]):
                 The request object. Request message for
                 [DataprocMetastore.Restore][].
             service (:class:`str`):
@@ -1191,17 +1193,17 @@ class DataprocMetastoreAsyncClient:
 
     async def list_backups(
         self,
-        request: metastore.ListBackupsRequest = None,
+        request: Union[metastore.ListBackupsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListBackupsAsyncPager:
         r"""Lists backups in a service.
 
         Args:
-            request (:class:`google.cloud.metastore_v1.types.ListBackupsRequest`):
+            request (Union[google.cloud.metastore_v1.types.ListBackupsRequest, dict]):
                 The request object. Request message for
                 [DataprocMetastore.ListBackups][google.cloud.metastore.v1.DataprocMetastore.ListBackups].
             parent (:class:`str`):
@@ -1273,17 +1275,17 @@ class DataprocMetastoreAsyncClient:
 
     async def get_backup(
         self,
-        request: metastore.GetBackupRequest = None,
+        request: Union[metastore.GetBackupRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> metastore.Backup:
         r"""Gets details of a single backup.
 
         Args:
-            request (:class:`google.cloud.metastore_v1.types.GetBackupRequest`):
+            request (Union[google.cloud.metastore_v1.types.GetBackupRequest, dict]):
                 The request object. Request message for
                 [DataprocMetastore.GetBackup][google.cloud.metastore.v1.DataprocMetastore.GetBackup].
             name (:class:`str`):
@@ -1344,19 +1346,19 @@ class DataprocMetastoreAsyncClient:
 
     async def create_backup(
         self,
-        request: metastore.CreateBackupRequest = None,
+        request: Union[metastore.CreateBackupRequest, dict] = None,
         *,
         parent: str = None,
         backup: metastore.Backup = None,
         backup_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Creates a new backup in a given project and location.
 
         Args:
-            request (:class:`google.cloud.metastore_v1.types.CreateBackupRequest`):
+            request (Union[google.cloud.metastore_v1.types.CreateBackupRequest, dict]):
                 The request object. Request message for
                 [DataprocMetastore.CreateBackup][google.cloud.metastore.v1.DataprocMetastore.CreateBackup].
             parent (:class:`str`):
@@ -1455,17 +1457,17 @@ class DataprocMetastoreAsyncClient:
 
     async def delete_backup(
         self,
-        request: metastore.DeleteBackupRequest = None,
+        request: Union[metastore.DeleteBackupRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Deletes a single backup.
 
         Args:
-            request (:class:`google.cloud.metastore_v1.types.DeleteBackupRequest`):
+            request (Union[google.cloud.metastore_v1.types.DeleteBackupRequest, dict]):
                 The request object. Request message for
                 [DataprocMetastore.DeleteBackup][google.cloud.metastore.v1.DataprocMetastore.DeleteBackup].
             name (:class:`str`):
