@@ -30,6 +30,8 @@ from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+OptionalRetry = Union[retries.Retry, object]
+
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.metastore_v1alpha.services.dataproc_metastore import pagers
@@ -434,7 +436,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         request: Union[metastore.ListServicesRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListServicesPager:
@@ -516,7 +518,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         request: Union[metastore.GetServiceRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> metastore.Service:
@@ -591,7 +593,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         parent: str = None,
         service: metastore.Service = None,
         service_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -705,7 +707,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         *,
         service: metastore.Service = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -805,7 +807,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         request: Union[metastore.DeleteServiceRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -899,7 +901,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         request: Union[metastore.ListMetadataImportsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListMetadataImportsPager:
@@ -981,7 +983,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         request: Union[metastore.GetMetadataImportRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> metastore.MetadataImport:
@@ -1056,7 +1058,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         parent: str = None,
         metadata_import: metastore.MetadataImport = None,
         metadata_import_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -1169,7 +1171,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         *,
         metadata_import: metastore.MetadataImport = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -1270,7 +1272,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         self,
         request: Union[metastore.ExportMetadataRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -1333,7 +1335,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         *,
         service: str = None,
         backup: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -1428,7 +1430,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         request: Union[metastore.ListBackupsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListBackupsPager:
@@ -1510,7 +1512,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         request: Union[metastore.GetBackupRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> metastore.Backup:
@@ -1583,7 +1585,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         parent: str = None,
         backup: metastore.Backup = None,
         backup_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -1692,7 +1694,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         request: Union[metastore.DeleteBackupRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
